"""
Enum of the logpolar parameters.

Author: Fabian A. Preiss
"""
from enum import Enum


class LogPolParams(Enum):
    REF_IMG = "REF_IMG"
    """Reference image."""
    MOD_IMG = "MOD_IMG"
    """Modified image."""
    GAUSS_DIFF = "GAUSS_DIFF"
    """Lower and upper kernel size of the DoG filter."""
    WINDOW_WEIGHT = "WINDOW_WEIGHT"
    """Weighting factor scaling beween windowed image and image, range of [0,1]."""
    WINDOW_TYPE = "WINDOW_TYPE"
    """Window type for FFT filter."""
    WINDOW_RADIUS_EXP = "WINDOW_RADIUS_EXP"
    """Window radius exponent, larger wrexp => faster computation."""
    UPSAMPLING = "UPSAMPLING"
    """Upsampling factor."""
    BOUNDS = "BOUNDS"
    """Boundaries for image slicing."""
    GAUSS_DIFF_REF_IMG = "GAUSS_DIFF_REF_IMG"
    """Gaussian difference filtered and windowed reference input image."""
    GAUSS_DIFF_MOD_IMG = "GAUSS_DIFF_MOD_IMG"
    """Gaussian difference filtered and windowed modified input image."""
    FOURIER_REF_IMG = "FOURIER_REF_IMG"
    """Fourier transformed and filtered reference image."""
    FOURIER_MOD_IMG = "FOURIER_MOD_IMG"
    """Fourier transformed and filtered modified image."""
    WARPED_FOURIER_REF_IMG = "WARPED_FOURIER_REF_IMG"
    """Log-polar transformed of the fourier transformed reference image."""
    WARPED_FOURIER_MOD_IMG = "WARPED_FOURIER_MOD_IMG"
    """Log-polar transformed of the fourier transformed modified image."""
    RECOVERED_ROTATION_SCALE_PHASE = "RECOVERED_ROTATION_SCALE_PHASE"
    """Recovered rotation angle in degrees and scaling factor including errors."""
    RECOVERED_ROTATION = "RECOVERED_ROTATION"
    """Recovered rotation angle and error in degrees."""
    RECOVERED_SCALE = "RECOVERED_SCALE"
    """Recovered scaling factor and error in degrees."""
    RECOVERED_ROT_SCALE_IMG = "RECOVERED_ROT_SCALE_IMG"
    """Rotation and scaling recovered image."""
    RECOVERED_TRANSLATION = "RECOVERED_TRANSLATION"
    """Recovered x,y translation vector and error."""
    RECOVERED_ROT_SCALE_TR_IMG = "RECOVERED_ROT_SCALE_TR_IMG"
    """Rotation, scaling and translation recovered image."""
